==> mx-datetime_23.4.tar.xz: mx-datetime-23.4/translations/mx-datetime_fr_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="604"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Date et Heure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Date &amp;&amp; Heure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="298"/>
        <location filename="../datetime.cpp" line="305"/>
        <source>Hardware Clock</source>
        <translation>Horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Outils de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Obtenir des informations depuis l’horloge matérielle et les afficher dans la case ci-dessous.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Lecture de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Appliquer des corrections de synchronisation systématiques à l’horloge matérielle.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Ajuster la synchronisation</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Transfert des horaires</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Faire immédiatement correspondre l’horloge système avec l’heure enregistrée dans l’horloge matérielle.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>De l’horloge matérielle vers l’horloge système</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Faire immédiatement correspondre l’horloge matérielle avec l’heure enregistrée dans l’horloge système.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>De l’horloge système vers l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Mettre à jour le facteur de synchronisation de l’horloge matérielle lorsqu’il est défini.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Mettre à jour la synchronisation</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Fuseau horaire de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Temps local</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Temps universel coordonné (ou Temps moyen de Greenwich)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Heure réseau</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Déplacer l’élément sélectionné vers le bas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Déplacer l’élément sélectionné vers le haut</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Supprimer l’élément de la liste</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Ajouter un élément à la liste</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Mettre automatiquement à jour l’horloge système grâce aux serveurs NTP:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Mettre à jour immédiatement l’horloge système grâce aux serveurs NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Mettre à jour maintenant</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Liste des serveurs NTP à utiliser.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="272"/>
        <source>Reading...</source>
        <translation>Lecture en cours...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="286"/>
        <source>Adjusting...</source>
        <translation>Ajustement...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="298"/>
        <location filename="../datetime.cpp" line="305"/>
        <source>System Clock</source>
        <translation>Horloge système</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="311"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>L’heure de %1 a été transférée à %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="314"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>L’heure de 1% n’a pas pu être transférée à %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="354"/>
        <source>Updating...</source>
        <translation>Mise à jour...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="367"/>
        <source>The system clock was updated successfully.</source>
        <translation>L’horloge système a été mise à jour avec succès.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="369"/>
        <source>The system clock could not be updated.</source>
        <translation>L’horloge système n’a pas pu être mise à jour.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="371"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Aucun des serveurs NTP dans la liste n’est actuellement actif.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="604"/>
        <source>About MX Date &amp; Time</source>
        <translation>À propos de MX Date et Heure</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="605"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="606"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Interface graphique permettant de définir l’heure et la date dans MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="608"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="610"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licence</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Journal des modifications</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annuler</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="616"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Aide MX Date et Heure</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fermer</translation>
    </message>
</context>
</TS>

==> mx-datetime_23.5.01.tar.xz: mx-datetime-23.5.01/translations/mx-datetime_fr_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="615"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Date et Heure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>À propos ...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Date &amp;&amp; Heure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>Hardware Clock</source>
        <translation>Horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Outils de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Obtenir des informations depuis l’horloge matérielle et les afficher dans la case ci-dessous.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Lecture de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Appliquer des corrections de synchronisation systématiques à l’horloge matérielle.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Ajuster la synchronisation</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Transfert des horaires</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Faire immédiatement correspondre l’horloge système avec l’heure enregistrée dans l’horloge matérielle.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>De l’horloge matérielle vers l’horloge système</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Faire immédiatement correspondre l’horloge matérielle avec l’heure enregistrée dans l’horloge système.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>De l’horloge système vers l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Mettre à jour le facteur de synchronisation de l’horloge matérielle lorsqu’il est défini.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Mettre à jour la synchronisation</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Fuseau horaire de l’horloge matérielle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Temps local</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Temps universel coordonné (ou Temps moyen de Greenwich)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Heure réseau</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Déplacer l’élément sélectionné vers le bas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Déplacer l’élément sélectionné vers le haut</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Supprimer l’élément de la liste</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Ajouter un élément à la liste</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Mettre automatiquement à jour l’horloge système grâce aux serveurs NTP:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Mettre à jour immédiatement l’horloge système grâce aux serveurs NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Mettre à jour maintenant</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Liste des serveurs NTP à utiliser.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="279"/>
        <source>Reading...</source>
        <translation>Lecture en cours ...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="293"/>
        <source>Adjusting...</source>
        <translation>Ajustement ...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>System Clock</source>
        <translation>Horloge système</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="318"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>L’heure de %1 a été transférée à %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="321"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>L’heure de 1% n’a pas pu être transférée à %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="361"/>
        <source>Updating...</source>
        <translation>Mise à jour ...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="375"/>
        <source>The system clock was updated successfully.</source>
        <translation>L’horloge système a été mise à jour avec succès.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="377"/>
        <source>The system clock could not be updated.</source>
        <translation>L’horloge système n’a pas pu être mise à jour.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="379"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Aucun des serveurs NTP dans la liste n’est actuellement actif.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="615"/>
        <source>About MX Date &amp; Time</source>
        <translation>À propos de MX Date et Heure</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="616"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="617"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Interface graphique permettant de définir l’heure et la date dans MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="619"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="621"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licence</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Journal des modifications</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annuler</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="627"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Aide MX Date et Heure</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation type="unfinished">Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Quitter</translation>
    </message>
</context>
</TS>
